@@ -1,3 +1,4 @@
+//
 // 
 //   Copyright (C) 2005, 2006 Free Software Foundation, Inc.
 // 
@@ -14,47 +15,38 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-// Linking Gnash statically or dynamically with other modules is making a
-// combined work based on Gnash. Thus, the terms and conditions of the GNU
-// General Public License cover the whole combination.
-//
-// As a special exception, the copyright holders of Gnash give you
-// permission to combine Gnash with free software programs or libraries
-// that are released under the GNU LGPL and with code included in any
-// release of Talkback distributed by the Mozilla Foundation. You may
-// copy and distribute such a system following the terms of the GNU GPL
-// for all but the LGPL-covered parts and Talkback, and following the
-// LGPL for the LGPL-covered parts.
-//
-// Note that people who make modified versions of Gnash are not obligated
-// to grant this special exception for their modified versions; it is their
-// choice whether to do so. The GNU General Public License gives permission
-// to release a modified version without this exception; this exception
-// also makes it possible to release a modified version which carries
-// forward this exception.
 // 
 //
 
+/* $Id: amf.cpp,v 1.19.2.3 2006/11/11 15:24:22 strk Exp $ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <cstdio>
-#include <cstring>
+//#include <cstring> //For memcoy(), commented out atm.
+#include <string>
+#include <vector>
 
-#if 0
-#include "log.h"
+#if defined(_WIN32) || defined(WIN32)
+#	include <Winsock2.h>
 #else
-// Define this to just use printf
-#define log_msg  printf
+#	include <netinet/in.h>
 #endif
-// #include "wchar.h"
-// #include "wctype.h"
-#include "stdlib.h"
+
+#include "log.h"
+#include "tu_swap.h"
 
 #include "amf.h"
 #include "amfutf8.h"
 
+using namespace std;
+using namespace gnash;
+
+namespace {
+gnash::LogFile& dbglogfile = gnash::LogFile::getDefaultInstance();
+}
+
 namespace amf 
 {
 
@@ -86,6 +78,43 @@ const char *response_str[] = {
     "/onDebugEvents"
 };
 
+AMF::AMF() 
+    : _type(NONE),
+      _amf_index(0),
+      _header_size(0),
+      _total_size(0),
+      _packet_size(0),
+      _amf_data(0),
+      _seekptr(0),
+      _mystery_word(0),
+      _src_dest(0)
+{
+    GNASH_REPORT_FUNCTION;
+}
+
+AMF::AMF(int size) 
+    : _type(NONE),
+      _amf_index(0),
+      _header_size(0),
+      _total_size(0),
+      _packet_size(0),
+      _amf_data(0),
+      _mystery_word(0),
+      _src_dest(0)
+{
+    GNASH_REPORT_FUNCTION;
+    if (!_amf_data) {
+        _amf_data = new unsigned char(size+1);
+        memset(_amf_data, 0, size+1);
+    }
+    _seekptr = _amf_data;
+}
+
+AMF::~AMF()
+{
+    GNASH_REPORT_FUNCTION;
+}
+
 
 /// \brief Swap bytes from big to little endian.
 ///
@@ -127,16 +156,32 @@ AMF::swapBytes(void *word, int size)
     return word;
 }
 
-// This returns the number of bytes read
-int
-AMF::readElement(void *out, void *in)
+
+bool
+AMF::parseAMF(char *in)
 {
+    GNASH_REPORT_FUNCTION;
+
+    char *x = static_cast<char *>(in);
+
+    while (*x != ObjectEnd) {
+        x = readElement(x);
+    }
+		return true;
+}
+
+char *
+AMF::readElement(void *in)
+{
+    GNASH_REPORT_FUNCTION;
+
     char *x = static_cast<char *>(in);
     astype_e type = (astype_e)*x;
     bool boolshift;
-    const char *mstr;    
+    const char *mstr = NULL;
     amfnum_t num;
     amfnum_t nanosecs;
+    short length;
     
     log_msg("Type is %s\n", astype_str[type]);
 
@@ -144,19 +189,19 @@ AMF::readElement(void *out, void *in)
     switch (type) {
       case Number:
           num = *(amfnum_t *)swapBytes(x+1, 8);
-          log_msg("Number is %lld", num);
-          return 8;
+          log_msg("Number is " AMFNUM_F, num);
           break;
       case Boolean:
           boolshift = *x;
           log_msg("Boolean is %d\n", boolshift);
-          return 1;
           break;
       case String:
 //        int length = *(short *)swapBytes(x, 2);
+          length = *(short *)x;
           x+=2;                  // skip the length bytes
-//          mstr = new char[length+1];
-//          memcpy(mstr, x, length);
+          mstr = new char[length+1];
+//           memset(mstr, 0, length+1);
+//           memcpy(mstr, x, length);
           // The function converts the multibyte string beginning at
           // *src to a sequence of wide characters as if by repeated
           // calls of the form:
@@ -164,61 +209,67 @@ AMF::readElement(void *out, void *in)
           log_msg("String is %s\n", mstr);
           break;
       case Object:
-//        log_msg("Object is unimplemented\n");
+//          readElement();
+          log_msg("Object is unimplemented\n");
           break;
       case MovieClip:
-//        log_msg("MovieClip is unimplemented\n");
+        log_msg("MovieClip is unimplemented\n");
+          break;
+      case Unsupported:
+        log_msg("MovieClip is unimplemented\n");
           break;
       case Null: 
-//        log_msg("Null is unimplemented\n");
+          log_msg("Null is unimplemented\n");
           break;
       case Undefined:
-//        log_msg("Endefined element");
-          return 1;
+          log_msg("Endefined element");
           break;
       case Reference:
-//          log_msg("Reference is unimplemented\n");
+          log_msg("Reference is unimplemented\n");
           break;
       case ECMAArray:
-//          log_msg("ECMAArray is unimplemented\n");
+          log_msg("ECMAArray is unimplemented\n");
           break;
       case ObjectEnd:
-//          log_msg("ObjectEnd is unimplemented\n");
+          log_msg("ObjectEnd is unimplemented\n");
           break;
       case StrictArray:
-//          log_msg("StrictArray is unimplemented\n");
+          log_msg("StrictArray is unimplemented\n");
           break;
       case Date:
-# if __WORDSIZE == 64
-          nanosecs = *(long *)swapBytes(x+1, 8);
-#else
-          nanosecs= *(long long *)swapBytes(x+1, 8);
-#endif
-           log_msg("Date is %lld nanoseconds\n", nanosecs);
-          return 8;
+          nanosecs = *(amfnum_t *)swapBytes(x+1, 8);
+          log_msg("Date is " AMFNUM_F " nanoseconds\n", nanosecs);
           break;
       case LongString:
-          int length = *(short *)swapBytes(x, 4);
+//          int length = *(short *)swapBytes(x, 4);
           x+=4;                  // skip the length bytes
 //        mstr = new char[length+1];
 //          memcpy(mstr, x, length);
           log_msg("String is %s\n", mstr);
           break;
 //       case Unsupported:
-// //          log_msg("Unsupported is unimplemented\n");
-//           break;
-//       case Recordset:
-// //          log_msg("Recordset is unimplemented\n");
-//           break;
-//       case XMLObject:
-// //          log_msg("XMLObject is unimplemented\n");
-//           break;
-//       case TypedObject:
-//           log_msg("TypedObject is unimplemented\n");
+          log_msg("Unsupported is unimplemented\n");
 //           break;
+      case Recordset:
+          log_msg("Recordset is unimplemented\n");
+          break;
+      case XMLObject:
+          log_msg("XMLObject is unimplemented\n");
+          break;
+      case TypedObject:
+          log_msg("TypedObject is unimplemented\n");
+          break;
     }
     
-    return 8;
+    return x;
+}
+
+bool
+AMF::readObject(void */* in */)
+{
+    GNASH_REPORT_FUNCTION;
+		return true;
+    
 }
 
 /// \brief Write an AMF element
@@ -241,7 +292,9 @@ AMF::readElement(void *out, void *in)
 void *
 AMF::encodeElement(astype_e type, void *in, int nbytes)
 {
-    char *out, *x;
+    GNASH_REPORT_FUNCTION;
+
+    char *out = NULL, *x;
     amfnum_t num;
     int pktsize;
 
@@ -393,84 +446,6 @@ AMF::encodeElement(astype_e type, void *in, int nbytes)
     
     return out;
 }
-
-AMF::astype_e
-AMF::extractElementHeader(void *in)
-{
-    return (AMF::astype_e)*(char *)in;
-}
-
-int
-AMF::extractElementLength(void *in)
-{
-    char *x = (char *)in;
-    astype_e type = (astype_e)*x;
-    x++;                        // skip the header byte
-    
-    switch (type) {
-      case Number:              // a 64 bit numeric value
-          return 8;
-          break;
-      case Boolean:             // a single byte
-          return 1;
-          break;
-      case String:              // the length is a 2 byte value
-          return (short)*(short *)x;
-          break;
-      case Object:
-          return (int)x - (int)strchr(x, TERMINATOR);
-          break;
-      case MovieClip:
-          return -1;
-          log_msg("MovieClip unimplemented");
-          break;
-      case Null: 
-          return -1;
-          log_msg("Null unimplemented");
-          break;
-      case Undefined:
-          return 0;
-          break;
-      case Reference:
-          return -1;
-          log_msg("Reference unimplemented");
-          break;
-      case ECMAArray:
-          return (int)x - (int)strchr(x, TERMINATOR);
-          break;
-      case ObjectEnd:
-          return -1;
-          log_msg("ObjectEnd unimplemented");
-          break;
-      case StrictArray:         // the length is a 4 byte value
-          return (int)*(int *)x;
-          break;
-      case Date:              // a 64 bit numeric value
-          return 8;
-          break;
-      case LongString:
-          return -1;
-          log_msg("LongString unimplemented");
-          break;
-      case Unsupported:
-          return -1;
-          log_msg("Unsupported unimplemented");
-          break;
-      case Recordset:
-          return -1;
-          log_msg("Recordset unimplemented");
-          break;
-      case XMLObject:           // the length is a 4 byte value
-          return (int)*(int *)x;
-          break;
-      case TypedObject:
-          return (int)x - (int)strchr(x, TERMINATOR);
-          break;
-    };
-    
-    return 0;
-}
-
 /// \brief Each header consists of the following:
 ///
 /// * UTF string (including length bytes) - name
@@ -480,14 +455,14 @@ AMF::extractElementLength(void *in)
 amfhead_t *
 AMF::encodeHeader(amfutf8_t *name, bool required, int nbytes, void *data)
 {
-    char *ptr;
-    AMF_Int_t length;
-    length = sizeof(amfhead_t) + nbytes + name->length + 1;
+    GNASH_REPORT_FUNCTION;
+
+    AMF_Int_t length = sizeof(amfhead_t) + nbytes + name->length + 1;
     char *buf = new char[length];
     memset(buf, 0, length);
-    ptr = buf;
+    char *ptr = buf;
 
-    // The first two bytes are the byte ciount for the UTF8 string,
+    // The first two bytes are the byte count for the UTF8 string,
     // which is in big-endian format.
     length = name->length;
     swapBytes(&length, sizeof(AMF_Int_t));
@@ -500,7 +475,7 @@ AMF::encodeHeader(amfutf8_t *name, bool required, int nbytes, void *data)
 
     // Then the "required" flag, whatever this does...
     memcpy(ptr, &required, 1);
-    ptr += 1;
+    ptr++;
 
     // Then the byte count of the data, which is an ActionScript
     // object
@@ -524,6 +499,8 @@ AMF::encodeHeader(amfutf8_t *name, bool required, int nbytes, void *data)
 amfbody_t *
 AMF::encodeBody(amfutf8_t *target, amfutf8_t *response, int nbytes, void *data)
 {
+    GNASH_REPORT_FUNCTION;
+
     char *buf = new char[sizeof(amfbody_t) + nbytes];
     memset(buf, 0, sizeof(amfbody_t) + nbytes );
     amfbody_t *body = (amfbody_t *)buf;
@@ -555,6 +532,8 @@ AMF::encodeBody(amfutf8_t *target, amfutf8_t *response, int nbytes, void *data)
 amfpacket_t *
 AMF::encodePacket(std::vector<amfhead_t *> messages)
 {
+    GNASH_REPORT_FUNCTION;
+
     int total = 0;
     amfpacket_t pkt;
     pkt.version = AMF_VERSION;
@@ -585,4 +564,438 @@ AMF::encodePacket(std::vector<amfhead_t *> messages)
     return out;
 }
 
+
+AMF::astype_e
+AMF::extractElementHeader(void *in)
+{
+    GNASH_REPORT_FUNCTION;
+
+    return (AMF::astype_e)*(char *)in;
+}
+
+int
+AMF::extractElementLength(void *in)
+{
+    GNASH_REPORT_FUNCTION;
+
+    char *x = (char *)in;
+    astype_e type = (astype_e)*x;
+    x++;                        // skip the header byte
+    
+    switch (type) {
+      case Number:              // a 64 bit numeric value
+          return 8;
+          break;
+      case Boolean:             // a single byte
+          return 1;
+          break;
+      case String:              // the length is a 2 byte value
+          return (short)*(short *)x;
+          break;
+      case Object:
+          return x - strchr(x, TERMINATOR);
+          break;
+      case MovieClip:
+          return -1;
+          log_msg("MovieClip unimplemented");
+          break;
+      case Null: 
+          return -1;
+          log_msg("Null unimplemented");
+          break;
+      case Undefined:
+          return 0;
+          break;
+      case Reference:
+          return -1;
+          log_msg("Reference unimplemented");
+          break;
+      case ECMAArray:
+          return x - strchr(x, TERMINATOR);
+          break;
+      case ObjectEnd:
+          return -1;
+          log_msg("ObjectEnd unimplemented");
+          break;
+      case StrictArray:         // the length is a 4 byte value
+//          return (int *)x;
+          break;
+      case Date:              // a 64 bit numeric value
+          return 8;
+          break;
+      case LongString:
+          return -1;
+          log_msg("LongString unimplemented");
+          break;
+      case Unsupported:
+          return -1;
+          log_msg("Unsupported unimplemented");
+          break;
+      case Recordset:
+          return -1;
+          log_msg("Recordset unimplemented");
+          break;
+      case XMLObject:           // the length is a 4 byte value
+//          return (int)*(int *)x;
+          break;
+      case TypedObject:
+          return x - strchr(x, TERMINATOR);
+          break;
+    };
+    
+    return 0;
+}
+
+std::string
+AMF::extractString(const char *in)
+{
+    GNASH_REPORT_FUNCTION;
+
+    int length;
+    
+    if (*in == 0) {
+        length = *(in+1);        
+    }
+		return "";
+}
+
+int
+AMF::extractNumber(const char */* in */)
+{
+    GNASH_REPORT_FUNCTION;    
+		return 0;	
+}
+
+int
+AMF::headerSize(char header)
+{
+//    GNASH_REPORT_FUNCTION;
+    
+    int headersize = -1;
+    
+    unsigned char hexint[2];
+    switch (header & AMF_HEADSIZE_MASK) {
+      case HEADER_12:
+          headersize = 12;
+          break;
+      case HEADER_8:
+          headersize = 8;
+          break;
+      case HEADER_4:
+          headersize = 4;
+          break;
+      case HEADER_1:
+          headersize = 11;
+          break;
+      default:
+          char buf = header & AMF_HEADSIZE_MASK;
+          hexify((unsigned char *)hexint, (unsigned char *)&buf, 1, false);
+          dbglogfile << "ERROR: Header size bits out of range! was 0x"
+                     << hexint << endl;
+          headersize = 1;
+          break;
+    };
+
+    return headersize;
+}
+
+int
+AMF::parseHeader(unsigned char *in)
+{
+    GNASH_REPORT_FUNCTION;
+
+    unsigned char *tmpptr = in;
+    unsigned char hexint[32];
+    
+    hexify((unsigned char *)hexint, (unsigned char *)tmpptr, 1, false);
+    dbglogfile << "AMF header byte is: 0x" << hexint << endl;
+
+    _amf_index = *tmpptr & AMF_INDEX_MASK;
+    _header_size = headerSize(*tmpptr++);
+
+#if 1
+    hexify((unsigned char *)hexint, (unsigned char *)in, _header_size, false);
+    dbglogfile << "The packet head is: 0x" << hexint << endl;
+#endif
+    if (_header_size >= 4) {
+        hexify((unsigned char *)hexint, (unsigned char *)tmpptr, 3, false);
+        _mystery_word = *tmpptr++;
+        _mystery_word = (_mystery_word << 12) + *tmpptr++;
+        _mystery_word = (_mystery_word << 8) + *tmpptr++;
+         dbglogfile << "The mystery word is: " << _mystery_word
+                    << " Hex value is: 0x" << hexint << endl;
+    }
+
+    if (_header_size >= 8) {
+        hexify((unsigned char *)hexint, (unsigned char *)tmpptr, 3, false);
+        _total_size = *tmpptr++;
+        _total_size = (_total_size << 12) + *tmpptr++;
+        _total_size = (_total_size << 8) + *tmpptr++;
+        _total_size = _total_size & 0x0000ff;
+        dbglogfile << "The body size is: " << _total_size
+                   << " Hex value is: 0x" << hexint << endl;
+        _amf_data = new unsigned char(_total_size+1);
+        _seekptr = _amf_data;
+//        memset(_amf_data, 0, _total_size+1);
+    }
+
+    if (_header_size >= 8) {
+        hexify((unsigned char *)hexint, (unsigned char *)tmpptr, 1, false);
+        _type = *(content_types_e *)tmpptr;
+        tmpptr++;
+        dbglogfile << "The type is: " << _type
+                   << " Hex value is: 0x" << hexint << endl;
+    }
+
+    switch(_type) {
+      case CHUNK_SIZE:
+      case BYTES_READ:
+      case PING:
+      case SERVER:
+      case CLIENT:
+      case VIDEO_DATA:
+      case NOTIFY:
+      case SHARED_OBJ:
+      case INVOKE:
+          _packet_size = AMF_VIDEO_PACKET_SIZE;
+          break;
+      case AUDIO_DATA:
+          _packet_size = AMF_AUDIO_PACKET_SIZE;
+          break;
+      default:
+          dbglogfile << "ERROR: Unidentified data type!" << endl;
+          break;
+    };
+    
+    if (_header_size == 12) {
+        hexify((unsigned char *)hexint, (unsigned char *)tmpptr, 3, false);
+        _src_dest = ntohl(*(unsigned int *)tmpptr);
+        tmpptr += sizeof(unsigned int);
+        dbglogfile << "The source/destination is: " << _src_dest
+                   << " Hex value is: 0x" << hexint << endl;
+    }
+
+    return _packet_size;
+}
+
+unsigned char *
+AMF::addPacketData(unsigned char *data, int bytes)
+{
+    GNASH_REPORT_FUNCTION;
+    memcpy(_seekptr, data, bytes);
+    _seekptr+=bytes;
+    return _seekptr;
+}
+
+int
+AMF::parseBody()
+{
+    GNASH_REPORT_FUNCTION;
+
+    return parseBody(_amf_data, _total_size);
+}
+
+int
+AMF::parseBody(unsigned char *in, int bytes)
+{
+    GNASH_REPORT_FUNCTION;
+
+    unsigned char *tmpptr;
+
+//    unsigned char hexint[(bytes*2)+1];
+    unsigned char* hexint;
+
+    char buffer[AMF_VIDEO_PACKET_SIZE+1];
+//    char *name;
+    short length;
+    amf_element_t el;
+
+    if (bytes == 0) {
+        return 0;
+    }
+    
+    if (in == 0) {
+        dbglogfile << "ERROR: input data is NULL!" << endl;
+        return -1;
+    }
+
+    hexint =  (unsigned char*) malloc((bytes * 2) + 12);
+
+//     memcpy(_amf_data +_read_size, in, AMF_VIDEO_PACKET_SIZE);
+//     _read_size += bytes;
+#if 1
+    hexify((unsigned char *)hexint, (unsigned char *)in, bytes, true);
+    dbglogfile << "The packet body is: 0x" << hexint << endl;
+#endif
+
+//    tmpptr = in;
+    tmpptr = in;
+    
+// All elements look like this:
+// the first two bytes is the length of name of the element
+// Then the next bytes are the element name
+// After the element name there is a type byte. If it's a Number type, then 8 bytes are read
+// If it's a String type, then there is a count of characters, then the string value    
+    
+    while (tmpptr  != (in + bytes)) {
+        memset(buffer, 0, AMF_VIDEO_PACKET_SIZE+1);
+        // Check the type of the element data
+        char type = *(astype_e *)tmpptr;
+        tmpptr++;                        // skip the header byte
+
+        switch ((astype_e)type) {
+          case Number:
+//              memcpy(buffer, tmpptr, 8);
+              tmpptr += 8;
+              continue;
+              break;
+          case Boolean:
+          case String:
+              dbglogfile << "AMF type: " << astype_str[(int)type] << ": a work in progress!" << endl;
+              // get the length of the name
+              length = ntohs(*(short *)tmpptr);
+              tmpptr += 2;
+              dbglogfile << "AMF String length is: " << length << endl;
+              // get the name of the element
+              if (length) {
+                  memcpy(buffer, tmpptr, length);
+              }
+              tmpptr += length;
+              dbglogfile << "AMF String is: " << buffer << endl;              
+              el.name = buffer;
+              break;
+          case Object:
+              dbglogfile << "AMF type: " << astype_str[(int)type] << ": a work in progress!" << endl;
+              do {
+                  tmpptr = extractVariables(el, tmpptr);
+              } while (el.type != ObjectEnd);
+              break;
+          case MovieClip:
+          case Null: 
+          case Undefined:
+          case Reference:
+          case ECMAArray:
+          case ObjectEnd:
+          case StrictArray:
+          case Date:
+          case LongString:
+          case Unsupported:
+          case Recordset:
+          case XMLObject:
+          case TypedObject:
+          default:
+//          dbglogfile << astype_str[(int)type] << ": unimplemented!" << endl;
+              dbglogfile << (int)type << ": unimplemented!" << endl;
+              return -1;
+        }
+    }
+
+    free(hexint);
+
+    return -1;
+}
+
+unsigned char *
+AMF::extractVariables(amf_element_t &el, unsigned char *in)
+{
+    GNASH_REPORT_FUNCTION;
+    
+    unsigned char buffer[AMF_VIDEO_PACKET_SIZE+1];
+    unsigned char *tmpptr = in;
+    short length = 0;
+
+    el.length = 0;
+    el.name.erase();
+    if (el.data) {
+        el.data = 0;
+    }
+    
+    memset(buffer, 0, AMF_VIDEO_PACKET_SIZE+1);
+    // @@ casting generic pointers to bigger types may be dangerous
+    //    due to memory alignment constraints
+    length = ntohs(*(const short *)tmpptr);
+    el.length = length;
+    if (length == 0) {
+        if (*(tmpptr+2) == ObjectEnd) {
+            dbglogfile << "End of Object definition." << endl;
+            el.length = 0;
+            el.type = ObjectEnd;
+            tmpptr+=3;
+            return tmpptr;
+        }
+    }
+    
+#if 1
+    unsigned char hexint[25];
+    hexify((unsigned char *)hexint, (unsigned char *)tmpptr, length+2, true);
+    dbglogfile << "The element is: 0x" << hexint << endl;
+#endif
+    tmpptr += 2;
+    dbglogfile << "AMF element length is: " << length << endl;
+    // get the name of the element
+    if (length) {
+        memcpy(buffer, tmpptr, length);
+        el.name = reinterpret_cast<char *>(buffer);
+        tmpptr += length;
+    } else {
+        // when reading in an object definition, a byte of 0x9 after
+        // a length of zero instead of the variable name.
+        if (*tmpptr == ObjectEnd) {
+            dbglogfile << "End of Object definition." << endl;
+            tmpptr++;
+            el.type = ObjectEnd;
+            el.name.erase();
+            el.length = 0;
+            el.data = 0;
+	    // @@ we're dropping constness of input here..
+	    //    it might be a problem, but strchr does it as well...
+            return tmpptr;
+        }
+    }
+    
+//    dbglogfile << "AMF element name is: " << buffer << endl;
+    char type = *(const astype_e *)tmpptr++;
+
+    if (type <= TypedObject) {
+        dbglogfile << "AMF type is: " << astype_str[(int)type] << endl;
+    }
+    
+    switch ((astype_e)type) {
+      case Number:
+          memcpy(buffer, tmpptr, 8);
+          swap64((uint64)*buffer);
+          dbglogfile << "Number \"" << el.name.c_str() << "\" is: " << (long)buffer << endl;
+          tmpptr += 8;
+          break;
+      case Boolean:
+      case String:
+          length = ntohs(*reinterpret_cast<const short *>(tmpptr)); // @@ this cast is dangerous due to memory alignment constraints
+          tmpptr += sizeof(short);
+          el.data = (const unsigned char*)tmpptr; 
+          dbglogfile << "Variable \"" << el.name.c_str() << "\" is: " << el.data << endl;
+          tmpptr += length;
+          el.length = length;
+          break;
+      case Object:
+      case MovieClip:
+      case Null: 
+      case Undefined:
+      case Reference:
+      case ECMAArray:
+      case ObjectEnd:
+      case StrictArray:
+      case Date:
+      case LongString:
+      case Unsupported:
+      case Recordset:
+      case XMLObject:
+      case TypedObject:
+//       default:
+//           dbglogfile << "astype_e of value: " << (int)type << " is unimplemented!" << endl;
+          break;
+    }
+    
+    return tmpptr; // we're dropping const specification
+}
+
 } // end of amf namespace
