@@ -9,7 +9,7 @@
 #ifndef UTF8_H
 #define UTF8_H
 
-
+#include "tu_config.h"
 #include "tu_types.h"
 
 
@@ -20,7 +20,7 @@ namespace utf8
 	// as output.  Advances *utf8_buffer past the character
 	// returned, unless the returned character is '\0', in which
 	// case the buffer does not advance.
-	Uint32	decode_next_unicode_character(const char** utf8_buffer);
+	DSOEXPORT uint32_t	decode_next_unicode_character(const char** utf8_buffer);
 
 	// Encodes the given UCS character into the given UTF-8
 	// buffer.  Writes the data starting at buffer[offset], and
@@ -28,7 +28,7 @@ namespace utf8
 	//
 	// May write up to 6 bytes, so make sure there's room in the
 	// buffer!
-	void	encode_unicode_character(char* buffer, int* offset, Uint32 ucs_character);
+	DSOEXPORT void	encode_unicode_character(char* buffer, int* offset, uint32_t ucs_character);
 }
 
 
