@@ -6,14 +6,15 @@
 // Utility kd-tree structure, for building kd-trees from triangle
 // soup.
 
-// #include <wctype.h>
-// #include <wchar.h>
-#include <stdio.h>
+// #include <cwctype>
+// #include <cwchar>
+#include <cstdio>
 
 #include "kd_tree_dynamic.h"
 #include "tu_file.h"
-#include <float.h>
+#include <cfloat>
 
+using namespace gnash;
 
 static const float	EPSILON = 1e-4f;
 static const int	LEAF_FACE_COUNT = 6;
@@ -56,7 +57,7 @@ void split_mesh(
 	std::vector<int>* tris0,
 	std::vector<vec3>* verts1,
 	std::vector<int>* tris1,
-	int vert_count,
+	int /* vert_count */,
 	const vec3 verts[],
 	int triangle_count,
 	const int indices[],
@@ -154,7 +155,7 @@ static void	remap_vertex_order(kd_tree_dynamic::node* node, hash<int,int>* map_i
 				{
 					// vert is not remapped yet; remap it.
 					map_indices_old_to_new->add(old_index, new_index);
-					(*new_vertex_count) += 1;
+					(*new_vertex_count)++;
 				}
 
 				// Remap.
@@ -612,7 +613,7 @@ void	kd_tree_dynamic::do_split(
 
 
 float	kd_tree_dynamic::evaluate_split(
-	int depth,
+	int /* depth */,
 	int face_count,
 	face faces[],
 	const axial_box& bounds,
@@ -990,8 +991,9 @@ static const int	Y_SIZE = 792;
 static const int	MARGIN = 20;
 
 
-struct kd_diagram_dump_info
+class kd_diagram_dump_info
 {
+public:
 	postscript*	m_ps;
 	int	m_depth;
 	int	m_max_depth;
