@@ -14,38 +14,20 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-// Linking Gnash statically or dynamically with other modules is making a
-// combined work based on Gnash. Thus, the terms and conditions of the GNU
-// General Public License cover the whole combination.
-//
-// As a special exception, the copyright holders of Gnash give you
-// permission to combine Gnash with free software programs or libraries
-// that are released under the GNU LGPL and with code included in any
-// release of Talkback distributed by the Mozilla Foundation. You may
-// copy and distribute such a system following the terms of the GNU GPL
-// for all but the LGPL-covered parts and Talkback, and following the
-// LGPL for the LGPL-covered parts.
-//
-// Note that people who make modified versions of Gnash are not obligated
-// to grant this special exception for their modified versions; it is their
-// choice whether to do so. The GNU General Public License gives permission
-// to release a modified version without this exception; this exception
-// also makes it possible to release a modified version which carries
-// forward this exception.
-// 
-//
+/* $Id: klash.cpp,v 1.17.2.7 2006/11/14 08:17:40 strk Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include <iostream>
 #include <unistd.h>
-#include <cstdlib>
+#include <cstdlib> //For exit()
 #include <cstdio>
 #include <vector>
+#include <sys/time.h>
+#include <ctime>
 
-#include <GL/gl.h>
-#include <GL/glu.h>
 #include <qapplication.h>
 #include <qgl.h>
 #include <qeventloop.h>
@@ -58,13 +40,15 @@
 
 #include "gnash.h"
 #include "log.h"
-#include "ogl.h"
+//#include "tu_opengl.h"
 #include "utility.h"
 #include "container.h"
 #include "tu_file.h"
 #include "tu_types.h"
 #include "xmlsocket.h"
-#include "Movie.h"
+#include "movie_definition.h"
+#include "URL.h"
+#include "rc.h"
 
 using namespace std;
 using namespace gnash;
@@ -95,14 +79,15 @@ typedef enum {IDLE_MOVIE, PLAY_MOVIE, RESTART_MOVIE, PAUSE_MOVIE, STOP_MOVIE, ST
 
 movie_state_e movie_menu_state;
 
-extern int mouse_x;
-extern int mouse_y;
-extern int mouse_buttons;
+int mouse_x;
+int mouse_y;
+int mouse_buttons;
 
-extern int width;
-extern int height;
+int width;
+int height;
+
+unsigned long windowid = 0;
 
-extern int windowid;
 class EmbedWidget : public QGLWidget
 {
     Q_OBJECT
@@ -223,6 +208,8 @@ void EmbedWidget::resizeEvent(QResizeEvent *event)
 //    this->resize(width, height);
 }
 
+// Registering a file opener has been obsoleted
+#if 0
 static tu_file*
 file_opener(const char* url)
 // Callback function.  This opens files for the library.
@@ -236,6 +223,8 @@ file_opener(const char* url)
         return new tu_file(url, "rb");
     }
 }
+#endif
+// 0
 
 static void
 fs_callback(gnash::movie_interface* movie, const char* command, const char* args)
@@ -260,12 +249,16 @@ main(int argc, char *argv[])
     assert(tu_types_validate());
     
     float	exit_timeout = 0;
-    bool do_render = true;
-    bool do_sound = false;
-    bool do_loop = true;
-    bool sdl_abort = true;
-    int  delay = 31;
+    bool        do_render = true;
+    bool        do_sound = true;
+    bool        do_loop = true;
+    bool        sdl_abort = true;
+    int         delay = 31;
     float	tex_lod_bias;
+    struct timeval now;
+    static struct timeval start;
+
+    unsigned int ticks;
     
     // -1.0 tends to look good.
     tex_lod_bias = -1.2f;
@@ -284,8 +277,36 @@ main(int argc, char *argv[])
         }
     }
 
+    gnash::LogFile& dbglogfile = gnash::LogFile::getDefaultInstance();
     dbglogfile.setWriteDisk(false);
     
+    RcInitFile& rcfile = RcInitFile::getDefaultInstance();
+    rcfile.loadFiles();
+//    rcfile.dump();
+
+    if (rcfile.useWriteLog()) {
+        dbglogfile.setWriteDisk(true);
+    }
+    
+    if (rcfile.verbosityLevel() > 0) {
+        dbglogfile.setVerbosity(rcfile.verbosityLevel());
+    }
+    
+    if (rcfile.useActionDump()) {
+        dbglogfile.setActionDump(true);
+        dbglogfile.setVerbosity();
+    }
+    
+    if (rcfile.useParserDump()) {
+        dbglogfile.setParserDump(true);
+        dbglogfile.setVerbosity();
+    }
+    
+    if (rcfile.getTimerDelay() > 0) {
+        delay = rcfile.getTimerDelay();
+        dbglogfile << "Timer delay set to " << delay << "milliseconds" << endl;
+    }
+
     while ((c = getopt (argc, argv, "hvaps:cfd:m:x:r:t:b:1ewj:k:u:")) != -1) {
 	switch (c) {
 	  case 'h':
@@ -300,10 +321,10 @@ main(int argc, char *argv[])
 	      dbglogfile << "Logging to disk enabled." << endl;
 	      break;
 	  case 'a':
-	      gnash::set_verbose_action(true);
+	      dbglogfile.setActionDump(true);              
 	      break;
 	  case 'p':
-	      gnash::set_verbose_parse(true);
+	      dbglogfile.setParserDump(true);
 	      break;
           case 'f':
               s_measure_performance = true;
@@ -399,16 +420,21 @@ main(int argc, char *argv[])
 	exit(1);
     }
 
-    gnash::register_file_opener_callback(file_opener);
+    // registering a file_opener has been obsoleted
+    //gnash::register_file_opener_callback(file_opener);
     gnash::register_fscommand_callback(fs_callback);
     
     gnash::sound_handler  *sound = NULL;
     gnash::render_handler *render = NULL;
     if (do_render) {
         if (do_sound) {
-#ifdef HAVE_SDL_MIXER_H
+#ifdef SOUND_SDL
             sound = gnash::create_sound_handler_sdl();
             gnash::set_sound_handler(sound);
+#endif
+#ifdef SOUND_GST
+            sound = gnash::create_sound_handler_gst();
+            gnash::set_sound_handler(sound);
 #endif
         }
         render = gnash::create_render_handler_ogl();
@@ -420,7 +446,7 @@ main(int argc, char *argv[])
     int	movie_width = 0;
     int	movie_height = 0;
     float	movie_fps = 30.0f;
-    gnash::get_movie_info(infiles[0], &movie_version, &movie_width,
+    gnash::get_movie_info(URL(infiles[0]), &movie_version, &movie_width,
                           &movie_height, &movie_fps, NULL, NULL);
     if (movie_version == 0) {
         fprintf(stderr, "error: can't get info about %s\n", infiles[0]);
@@ -481,7 +507,7 @@ main(int argc, char *argv[])
     }
     
     // Load the actual movie.
-    gnash::movie_definition*	md = gnash::create_library_movie(infiles[0]);
+    gnash::movie_definition*	md = gnash::create_library_movie(URL(infiles[0]));
     if (md == NULL) {
         fprintf(stderr, "error: can't create a movie from '%s'\n", infiles[0]);
         exit(1);
@@ -495,22 +521,24 @@ main(int argc, char *argv[])
     
     // Mouse state.
     float	speed_scale = 1.0f;
-    Uint32	start_ticks = 0;
+    unsigned int start_ticks = 0;
+    gettimeofday(&start, NULL);
     if (do_render) {
-        start_ticks = SDL_GetTicks();
-        
+        gettimeofday(&now, NULL);
+	start_ticks=(now.tv_sec-start.tv_sec)*1000+(now.tv_usec-start.tv_usec)/1000;        
     }
-    Uint32	last_ticks = start_ticks;
+    unsigned int last_ticks = start_ticks;
     int	frame_counter = 0;
     int	last_logged_fps = last_ticks;    
     
     for (;;) {
-        Uint32	ticks;
+        uint32_t	ticks;
         if (do_render) {
-            ticks = SDL_GetTicks();
+            gettimeofday(&now, NULL);
+            ticks=(now.tv_sec-start.tv_sec)*1000+(now.tv_usec-start.tv_usec)/1000;      
         } else {
             // Simulate time.
-            ticks = last_ticks + (Uint32) (1000.0f / movie_fps);
+            ticks = last_ticks + (uint32_t) (1000.0f / movie_fps);
         }
         int	delta_ticks = ticks - last_ticks;
         float	delta_t = delta_ticks / 1000.f;
@@ -518,7 +546,7 @@ main(int argc, char *argv[])
         
         // Check auto timeout counter.
         if (exit_timeout > 0
-            && ticks - start_ticks > (Uint32) (exit_timeout * 1000)) {
+            && ticks - start_ticks > (uint32_t) (exit_timeout * 1000)) {
             // Auto exit now.
             break;
         }
