@@ -38,7 +38,8 @@
 #include "prcpucfg.h"
 #endif
 
-#include <stddef.h>
+#include <cstddef>
+using namespace std;
 
 /***********************************************************************
 ** MACROS:      PR_EXTERN
