@@ -14,28 +14,12 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-// Linking Gnash statically or dynamically with other modules is making a
-// combined work based on Gnash. Thus, the terms and conditions of the GNU
-// General Public License cover the whole combination.
-//
-// As a special exception, the copyright holders of Gnash give you
-// permission to combine Gnash with free software programs or libraries
-// that are released under the GNU LGPL and with code included in any
-// release of Talkback distributed by the Mozilla Foundation. You may
-// copy and distribute such a system following the terms of the GNU GPL
-// for all but the LGPL-covered parts and Talkback, and following the
-// LGPL for the LGPL-covered parts.
-//
-// Note that people who make modified versions of Gnash are not obligated
-// to grant this special exception for their modified versions; it is their
-// choice whether to do so. The GNU General Public License gives permission
-// to release a modified version without this exception; this exception
-// also makes it possible to release a modified version which carries
-// forward this exception.
 // 
 //
 //
 
+/* $Id: xml.cpp,v 1.31.2.1 2006/10/30 14:28:49 rsavoye Exp $ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -46,11 +30,12 @@
 #include <vector>
 
 #include "log.h"
-#include "action.h"
-#include "impl.h"
-#include "smart_ptr.h"
+//#include "action.h"
+//#include "impl.h"
+//#include "smart_ptr.h"
 #include "tu_config.h"
-#include "Function.h"
+#include "as_function.h" // for as_function
+#include "fn_call.h"
 
 #ifdef HAVE_LIBXML
 
@@ -94,7 +79,7 @@ XML::XML(tu_string xml_in)
     parseXML(xml_in);
 }
 
-XML::XML(struct node *childNode)
+XML::XML(struct node */* childNode */)
 {
     GNASH_REPORT_FUNCTION;
 #ifdef DEBUG_MEMORY_ALLOCATION
@@ -123,7 +108,7 @@ XML::~XML()
 const char *
 XML::nodeName()
 {
-  printf("%s: XML %p _nodes at %p\n", __PRETTY_FUNCTION__, this, _nodes);
+  printf("%s: XML %p _nodes at %p\n", __PRETTY_FUNCTION__, (void*)this, (void*)_nodes);
   if (_nodes) {
     return _nodes->nodeName();
   }
@@ -133,7 +118,7 @@ XML::nodeName()
 const char *
 XML::nodeValue()
 {
-  printf("%s: XML _nodes at %p\n", __PRETTY_FUNCTION__, _nodes);
+  printf("%s: XML _nodes at %p\n", __PRETTY_FUNCTION__, (void*)_nodes);
   if (_nodes) {
     return _nodes->nodeValue();
   }
@@ -141,33 +126,35 @@ XML::nodeValue()
 }
 
 void
-XML::nodeNameSet(char *name)
+XML::nodeNameSet(char */*name */)
 {
   if (!_nodes) {
     _nodes = new XMLNode;
-    printf("%s: New XML %p _nodes at %p\n", __PRETTY_FUNCTION__, this, _nodes);
+    printf("%s: New XML %p _nodes at %p\n", __PRETTY_FUNCTION__, (void*)this, (void*)_nodes);
   }
   //  _nodes->nodeNameSet(name);
-  printf("%s: XML %p _name at %p, %s\n", __PRETTY_FUNCTION__, this,
-	 _nodes->nodeName(),_nodes->nodeName() );
+  printf("%s: XML %p _name at %p, %s\n", __PRETTY_FUNCTION__, (void*)this,
+	 _nodes->nodeName(), _nodes->nodeName() );
 }
 
 void
-XML::nodeValueSet(char *value)
+XML::nodeValueSet(char */* value */)
 {
   if (!_nodes) {
     _nodes = new XMLNode;
-    printf("%s: New XML _nodes at %p\n", __PRETTY_FUNCTION__, _nodes);
+    printf("%s: New XML _nodes at %p\n", __PRETTY_FUNCTION__, (void*)_nodes);
   }
   
   //  _nodes->nodeValueSet(value);
-  printf("%s: XML _nodes at %p\n", __PRETTY_FUNCTION__, _nodes);
+  printf("%s: XML _nodes at %p\n", __PRETTY_FUNCTION__, (void*)_nodes);
 }
 
 // Dispatch event handler(s), if any.
 bool
-XML::on_event(event_id id)
+XML::on_event(event_id /* id */)
 {
+    GNASH_REPORT_FUNCTION;
+    
     // Keep m_as_environment alive during any method calls!
     //  smart_ptr<as_object_interface>	this_ptr(this);
   
@@ -290,7 +277,8 @@ XML::extractNode(xmlNodePtr node, bool mem)
 bool
 XML::parseDoc(xmlDocPtr document, bool mem)
 {
-    log_msg("%s:\n", __PRETTY_FUNCTION__);
+    GNASH_REPORT_FUNCTION;
+    
     XMLNode *top;
     xmlNodePtr cur;
 
@@ -320,8 +308,6 @@ XML::parseXML(tu_string xml_in)
 {
     GNASH_REPORT_FUNCTION;
 
-    bool        ret = true;
-
     log_msg("Parse XML from memory: %s\n", xml_in.c_str());
 
     if (xml_in.size() == 0) {
@@ -333,13 +319,15 @@ XML::parseXML(tu_string xml_in)
     //dump_memory_stats(__FUNCTION__, __LINE__, "before xmlParseMemory");
 #endif
 
+    _bytes_total = _bytes_loaded = xml_in.size();
+    
 #ifdef USE_XMLREADER
     XMLNode *node = 0;
     xmlTextReaderPtr reader;
 
     reader = xmlReaderForMemory(xml_in.c_str(), xml_in.size(), NULL, NULL, 0);
     if (reader != NULL) {
-        ret = true;
+	bool ret = true;
         while (ret) {
             ret = xmlTextReaderRead(reader);
             node = processNode(reader, node);
@@ -356,6 +344,9 @@ XML::parseXML(tu_string xml_in)
     xmlCleanupParser();
     return true;
 #else
+
+bool ret = true;
+
 #ifdef USE_DOM
     xmlInitParser();
   
@@ -372,7 +363,6 @@ XML::parseXML(tu_string xml_in)
 #ifndef USE_DMALLOC
     //dump_memory_stats(__FUNCTION__, __LINE__, "after xmlParseMemory");
 #endif
-
     return ret;
 #endif
   
@@ -515,7 +505,7 @@ XML::processNode(xmlTextReaderPtr reader, XMLNode *node)
 bool
 XML::load(const char *filespec)
 {
-    bool ret = true;
+    GNASH_REPORT_FUNCTION;
     struct stat stats;
     log_msg("Load disk XML file: %s\n", filespec);
   
@@ -534,7 +524,7 @@ XML::load(const char *filespec)
   
     reader = xmlNewTextReaderFilename(filespec);
     if (reader != NULL) {
-        ret = true;
+        bool ret = true;
         while (ret) {
             ret = xmlTextReaderRead(reader);
             node = processNode(reader, node);
@@ -558,7 +548,7 @@ XML::load(const char *filespec)
         log_error("Can't load XML file: %s!\n", filespec);
         return false;
     }
-    ret = parseDoc(_doc, false);
+    parseDoc(_doc, false);
     xmlCleanupParser();
     xmlFreeDoc(_doc);
     xmlMemoryDump();
@@ -596,7 +586,7 @@ XML::operator [] (int x) {
 }
 
 void
-XML::cleanupStackFrames(XMLNode *xml)
+XML::cleanupStackFrames(XMLNode */* xml */)
 {
     GNASH_REPORT_FUNCTION;
 }
@@ -604,6 +594,8 @@ XML::cleanupStackFrames(XMLNode *xml)
 as_object *
 XML::setupFrame(as_object *obj, XMLNode *xml, bool mem)
 {
+//    GNASH_REPORT_FUNCTION;
+    
     int		 child;
     unsigned int i;
     const char    *nodename;
@@ -631,7 +623,7 @@ XML::setupFrame(as_object *obj, XMLNode *xml, bool mem)
     obj->set_member("length",             length);
     if (xml->_value != 0) {
         obj->set_member("nodeValue",        xml->_value);
-        //log_msg("\tnodevalue for %s is: %s\n", nodename, xml->_value);
+        log_msg("\tnodevalue for %s is: %s\n", nodename, xml->_value);
     } else {
         obj->set_member("nodeValue", as_value::UNDEFINED);
     }
@@ -654,9 +646,9 @@ XML::setupFrame(as_object *obj, XMLNode *xml, bool mem)
         attr_obj = new xmlattr_as_object;
         for (i=0; i<xml->_attributes.size(); i++) {
             attr_obj->set_member(xml->_attributes[i]->_name, xml->_attributes[i]->_value);
-//        log_msg("\t\tAdding attribute as member %s, value is %s to node %s (%p)\n",
-//                xml->_attributes[i]->_name,
-//                xml->_attributes[i]->_value, nodename, obj);
+	    log_msg("\t\tAdding attribute as member %s, value is %s to node %s (%p)\n",
+		    xml->_attributes[i]->_name,
+		    xml->_attributes[i]->_value, nodename, static_cast<void*>(obj) );
         }
         obj->set_member("attributes", attr_obj);
     }
@@ -704,7 +696,7 @@ XML::setupFrame(as_object *obj, XMLNode *xml, bool mem)
 /// If multiple calls are made to set the same header name, each
 /// successive value replaces the value set in the previous call.
 void
-XML::addRequestHeader(const char *name, const char *value)
+XML::addRequestHeader(const char */* name */, const char */* value */)
 {
     log_msg("%s:unimplemented \n", __FUNCTION__);
 }
@@ -762,7 +754,7 @@ XML::cloneNode(XMLNode &newnode, bool deep)
 /// the XML.createTextNode() method are the constructor methods for
 /// creating nodes for an XML object. 
 XMLNode *
-XML::createElement(const char *name)
+XML::createElement(const char */* name */)
 {
     log_msg("%s:unimplemented \n", __FUNCTION__);
     return (XMLNode*)0;
@@ -777,7 +769,7 @@ XML::createElement(const char *name)
 /// XML.createElement() method are the constructor methods for
 /// creating nodes for an XML object.
 XMLNode *
-XML::createTextNode(const char *name)
+XML::createTextNode(const char */* name */)
 {
     log_msg("%s:unimplemented \n", __FUNCTION__);
     return (XMLNode*)0;
@@ -791,7 +783,7 @@ XML::createTextNode(const char *name)
 /// method. If beforeNode is not a child of my_xml, the insertion
 /// fails.
 void
-XML::insertBefore(XMLNode *newnode, XMLNode *node)
+XML::insertBefore(XMLNode */* newnode */, XMLNode */* node */)
 {
     log_msg("%s:unimplemented \n", __FUNCTION__);
 }
@@ -805,7 +797,7 @@ XML::load()
 void
 XML::parseXML()
 {
-    log_msg("%s:unimplemented \n", __FUNCTION__);
+    log_msg("%s: unimplemented \n", __FUNCTION__);
 }
 
 /// \brief removes the specified XML object from its parent. Also
@@ -847,7 +839,7 @@ XML::stringify(XMLNode *xml)
     int           length;
     string	  str;
     
-    log_msg("%s: processing for object %p\n", __PRETTY_FUNCTION__, this);
+    log_msg("%s: processing for object %p\n", __PRETTY_FUNCTION__, (void*)this);
   
     // Process the attributes, if any
     if (_nodes->_attributes.size() == 0) {
@@ -862,7 +854,7 @@ XML::stringify(XMLNode *xml)
 
     vector<XMLNode *>::iterator it;
     for (it = _nodes->_children.begin(); it != _nodes->_children.end(); ++it) {
-	log_msg("Found One!!!! %p\n", *it);
+	log_msg("Found One!!!! %p\n", (void*)*it);
     }
     
     // Process the children, if there are any
@@ -871,7 +863,7 @@ XML::stringify(XMLNode *xml)
     if (length) {
         log_msg("\tProcessing %d children nodes\n", length);
         for (child=0; child<length; child++) {
-	    log_msg("Name %p\n", xml->_children[child]);
+	    log_msg("Name %p\n", (void*)(xml->_children[child]));
 	    if (xml->_children[child]->_name) {
 //		log_msg("Name %p", xml->_children[child]);
 	    }
@@ -899,12 +891,11 @@ xml_load(const fn_call& fn)
     bool          ret;
     struct stat   stats;
 
-
-    //log_msg("%s:\n", __FUNCTION__);
+    //GNASH_REPORT_FUNCTION;
   
     xml_as_object *xml_obj = (xml_as_object*)fn.this_ptr;
   
-    const tu_string filespec = fn.env->bottom(fn.first_arg_bottom_index).to_string();
+    const std::string filespec = fn.env->bottom(fn.first_arg_bottom_index).to_string();
 
     // If the file doesn't exist, don't try to do anything.
     if (stat(filespec.c_str(), &stats) < 0) {
@@ -923,8 +914,6 @@ xml_load(const fn_call& fn)
     }
     
     //env->bottom(first_arg) = ret;
-    std::vector<with_stack_entry> with_stack;
-    std::vector<with_stack_entry> dummy_stack;
     //  struct node *first_node = ptr->obj.firstChildGet();
   
     //const char *name = ptr->obj.nodeNameGet();
@@ -937,23 +926,20 @@ xml_load(const fn_call& fn)
 #if 1
     if (fn.this_ptr->get_member("onLoad", &method)) {
         //    log_msg("FIXME: Found onLoad!\n");
-        fn.env->set_variable("success", true, std::vector<with_stack_entry>());
+        fn.env->set_variable("success", true);
         fn.env->bottom(fn.first_arg_bottom_index) = true;
         as_c_function_ptr	func = method.to_c_function();
-        if (func)
-            {
-                // It's a C function.  Call it.
-                log_msg("Calling C function for onLoad\n");
-                (*func)(fn_call(&val, xml_obj, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
-            }
-        else if (function_as_object* as_func = method.to_as_function())
-            {
-                // It's an ActionScript function.  Call it.
-                log_msg("Calling ActionScript function for onLoad\n");
-                (*as_func)(fn_call(&val, xml_obj, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
-            } else {
-                log_error("error in call_method(): method is not a function\n");
-            }
+        if (func) {
+	    // It's a C function.  Call it.
+	    log_msg("Calling C function for onLoad\n");
+	    (*func)(fn_call(&val, xml_obj, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
+	} else if (as_function* as_func = method.to_as_function()) {
+	    // It's an ActionScript function.  Call it.
+	    log_msg("Calling ActionScript function for onLoad\n");
+	    (*as_func)(fn_call(&val, xml_obj, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
+	} else {
+	    log_error("error in call_method(): method is not a function\n");
+	}
     } else {
         log_msg("Couldn't find onLoad event handler, setting up callback\n");
         // ptr->set_event_handler(event_id::XML_LOAD, (as_c_function_ptr)&xml_onload);
@@ -976,7 +962,6 @@ xml_onload(const fn_call& fn)
     as_value	method;
     as_value      val;
     static bool first = true;     // This event handler should only be executed once.
-    std::vector<with_stack_entry>	empty_with_stack;
     xml_as_object*	ptr = (xml_as_object*) (as_object*) fn.this_ptr;
     assert(ptr);
   
@@ -1000,7 +985,7 @@ xml_onload(const fn_call& fn)
                     log_msg("Calling C function for onLoad\n");
                     (*func)(fn_call(&val, fn.this_ptr, fn.env, 0, 0));
                 }
-            else if (function_as_object* as_func = method.to_as_function())
+            else if (as_function* as_func = method.to_as_function())
                 {
                     // It's an ActionScript function.  Call it.
                     log_msg("Calling ActionScript function for onLoad\n");
@@ -1035,14 +1020,14 @@ xml_ondata(const fn_call& fn)
         if (fn.this_ptr->get_member("onData", &method)) {
             log_msg("FIXME: Found onData!\n");
             as_c_function_ptr	func = method.to_c_function();
-            fn.env->set_variable("success", true, std::vector<with_stack_entry>());
+            fn.env->set_variable("success", true);
             if (func)
                 {
                     // It's a C function.  Call it.
                     log_msg("Calling C function for onData\n");
                     (*func)(fn_call(&val, fn.this_ptr, fn.env, 0, 0));
                 }
-            else if (function_as_object* as_func = method.to_as_function())
+            else if (as_function* as_func = method.to_as_function())
                 {
                     // It's an ActionScript function.  Call it.
                     log_msg("Calling ActionScript function for onData\n");
@@ -1135,7 +1120,7 @@ xml_loaded(const fn_call& fn)
     
     xml_as_object*	ptr = (xml_as_object*) (as_object*) fn.this_ptr;
     assert(ptr);
-    tu_string filespec = fn.env->bottom(fn.first_arg_bottom_index).to_string();
+    std::string filespec = fn.env->bottom(fn.first_arg_bottom_index).to_string();
     //fn.result->set(ptr->obj.loaded());
     fn.result->set_bool(ptr->obj.loaded());
 }
@@ -1258,12 +1243,45 @@ void xml_insertbefore(const fn_call& fn)
 }
 void xml_parsexml(const fn_call& fn)
 {
+    const char *text;
+    as_value	method;
+    as_value	val;    
     xml_as_object *ptr = (xml_as_object*)fn.this_ptr;
     assert(ptr);
+
+    if (fn.nargs > 0) {
+        text = fn.env->bottom(fn.first_arg_bottom_index).to_string();
+	ptr->obj.parseXML(text);
+	ptr->obj.setupFrame(ptr, ptr->obj.firstChild(), false);  
+    }
     
+#if 1
+    if (fn.this_ptr->get_member("onLoad", &method)) {
+        //    log_msg("FIXME: Found onLoad!\n");
+        fn.env->set_variable("success", true);
+        fn.env->bottom(fn.first_arg_bottom_index) = true;
+        as_c_function_ptr	func = method.to_c_function();
+        if (func) {
+	    // It's a C function.  Call it.
+	    log_msg("Calling C function for onLoad\n");
+	    (*func)(fn_call(&val, ptr, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
+	} else if (as_function* as_func = method.to_as_function()) {
+	    // It's an ActionScript function.  Call it.
+	    log_msg("Calling ActionScript function for onLoad\n");
+	    (*as_func)(fn_call(&val, ptr, fn.env, fn.nargs, fn.first_arg_bottom_index)); // was this_ptr instead of node
+	} else {
+	    log_error("error in call_method(): method is not a function\n");
+	}
+    } else {
+        log_msg("Couldn't find onLoad event handler, setting up callback\n");
+        // ptr->set_event_handler(event_id::XML_LOAD, (as_c_function_ptr)&xml_onload);
+    }
+#else
+    
+#endif
 //    fn.result->set_int(ptr->obj.getAllocated());
-    ptr->obj.parseXML();
 }
+    
 void xml_removenode(const fn_call& fn)
 {
     xml_as_object *ptr = (xml_as_object*)fn.this_ptr;
