@@ -14,24 +14,6 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-// Linking Gnash statically or dynamically with other modules is making a
-// combined work based on Gnash. Thus, the terms and conditions of the GNU
-// General Public License cover the whole combination.
-//
-// As a special exception, the copyright holders of Gnash give you
-// permission to combine Gnash with free software programs or libraries
-// that are released under the GNU LGPL and with code included in any
-// release of Talkback distributed by the Mozilla Foundation. You may
-// copy and distribute such a system following the terms of the GNU GPL
-// for all but the LGPL-covered parts and Talkback, and following the
-// LGPL for the LGPL-covered parts.
-//
-// Note that people who make modified versions of Gnash are not obligated
-// to grant this special exception for their modified versions; it is their
-// choice whether to do so. The GNU General Public License gives permission
-// to release a modified version without this exception; this exception
-// also makes it possible to release a modified version which carries
-// forward this exception.
 // 
 //
 //
@@ -40,34 +22,34 @@
 #include "config.h"
 #endif
 
-#include <SDL.h>
-
 #include "utility.h"
-#include "log.h"
 #include "xml.h"
 #include "xmlsocket.h"
 #include "timers.h"
-#include "Function.h"
+#include "as_function.h"
+#include "fn_call.h"
+#include "sprite_instance.h"
 
 #ifdef HAVE_LIBXML
 
+#include "log.h"
+
 #include <sys/types.h>
+#include <fcntl.h>
 #ifdef HAVE_WINSOCK
 # include <WinSock2.h>
 # include <windows.h>
-# include <fcntl.h>
 # include <sys/stat.h>
 # include <io.h>
 #else
 # include <sys/time.h>
-# include <sys/fcntl.h>
 # include <unistd.h>
 # include <sys/select.h>
 # include <netinet/in.h>
 # include <arpa/inet.h>
 # include <sys/socket.h>
 # include <netdb.h>
-# include <errno.h>
+# include <cerrno>
 # include <sys/param.h>
 # include <sys/select.h>
 #endif
@@ -394,7 +376,7 @@ XMLSocket::anydata(int fd, char **msgs)
 }
 
 bool
-XMLSocket::send(tu_string str)
+XMLSocket::send(std::string str)
 {
   //GNASH_REPORT_FUNCTION;
   
@@ -402,7 +384,7 @@ XMLSocket::send(tu_string str)
   int ret = write(_sockfd, str.c_str(), str.size());
 
   //log_msg("%s: sent %d bytes, data was %s\n", __FUNCTION__, ret, str.c_str());
-  if (ret == str.size()) {
+  if (ret == static_cast<signed int>(str.size())) {
     return true;
   } else {
     return false;
@@ -412,25 +394,25 @@ XMLSocket::send(tu_string str)
 // Callbacks
 
 void
-XMLSocket::onClose(tu_string str)
+XMLSocket::onClose(std::string /* str */)
 {
   log_msg("%s: \n", __FUNCTION__);
 }
 
 void
-XMLSocket::onConnect(tu_string str)
+XMLSocket::onConnect(std::string /* str */)
 {
   log_msg("%s: \n", __FUNCTION__);
 }
 
 void
-XMLSocket::onData(tu_string str)
+XMLSocket::onData(std::string /* str */)
 {
   log_msg("%s: \n", __FUNCTION__);
 }
 
 void
-XMLSocket::onXML(tu_string str)
+XMLSocket::onXML(std::string /* str */)
 {
   log_msg("%s: \n", __FUNCTION__);
 }
@@ -503,8 +485,6 @@ xmlsocket_connect(const fn_call& fn)
   as_value	method;
   as_value	val;
   static bool first = true;     // This event handler should only be executed once.
-  bool          ret;
-  const std::vector<with_stack_entry> with_stack;
 
   if (!first) {
     fn.result->set_bool(true);
@@ -514,12 +494,13 @@ xmlsocket_connect(const fn_call& fn)
   log_msg("%s: nargs=%d\n", __FUNCTION__, fn.nargs);
   xmlsocket_as_object*	ptr = (xmlsocket_as_object*) (as_object*) fn.this_ptr;
   assert(ptr);
-  const tu_string host = fn.env->bottom(fn.first_arg_bottom_index).to_string();
-  tu_string port_str = fn.env->bottom(fn.first_arg_bottom_index-1).to_tu_string();
+  const std::string host = fn.env->bottom(fn.first_arg_bottom_index).to_string();
+  std::string port_str = fn.env->bottom(fn.first_arg_bottom_index-1).to_string();
   double port = atof(port_str.c_str());
-  ret = ptr->obj.connect(host.c_str(), static_cast<int>(port));
 
-#if 0
+  ptr->obj.connect(host.c_str(), static_cast<int>(port));
+
+#if 0 // use connect return as result
   // Push result onto stack for onConnect
   if (ret) {
     fn.env->push(as_value(true));
@@ -540,7 +521,7 @@ xmlsocket_connect(const fn_call& fn)
       log_msg("Calling C function for onConnect\n");
       (*func)(fn_call(&val, fn.this_ptr, fn.env, 0, 0));
     }
-    else if (function_as_object* as_func = method.to_as_function()) {
+    else if (as_function* as_func = method.to_as_function()) {
       // It's an ActionScript function.  Call it.
       log_msg("Calling ActionScript function for onConnect\n");
       (*as_func)(fn_call(&val, fn.this_ptr, fn.env, 2, 2));
@@ -575,7 +556,7 @@ xmlsocket_send(const fn_call& fn)
   
   xmlsocket_as_object*	ptr = (xmlsocket_as_object*) (as_object*) fn.this_ptr;
   assert(ptr);
-  const tu_string object = fn.env->bottom( fn.first_arg_bottom_index).to_string();
+  const std::string object = fn.env->bottom( fn.first_arg_bottom_index).to_string();
   //  log_msg("%s: host=%s, port=%g\n", __FUNCTION__, host, port);
   fn.result->set_bool(ptr->obj.send(object));
 }
@@ -670,8 +651,7 @@ xmlsocket_event_ondata(const fn_call& fn)
   char          *messages[200];
   int           i;
   as_c_function_ptr	func;
-  function_as_object*       as_func;
-  tu_string     data; 
+  as_function*       as_func;
 
   xmlsocket_as_object*	ptr = (xmlsocket_as_object*)fn.this_ptr;
   assert(ptr);
@@ -742,7 +722,7 @@ xmlsocket_event_ondata(const fn_call& fn)
 }
 
 void
-xmlsocket_event_close(const fn_call& fn)
+xmlsocket_event_close(const fn_call& /* fn */)
 {
 #if 0
   as_value* result = fn.result;
@@ -759,7 +739,6 @@ xmlsocket_event_connect(const fn_call& fn)
 {
   as_value	method;
   as_value	val;
-  tu_string     data;
   static bool first = true;     // This event handler should only be executed once.
 
   if (!first) {
@@ -784,7 +763,7 @@ xmlsocket_event_connect(const fn_call& fn)
           //log_msg("Calling C function for onConnect\n");
           (*func)(fn_call(&val, fn.this_ptr, fn.env, 0, 0));
       }
-      else if (function_as_object* as_func = method.to_as_function())
+      else if (as_function* as_func = method.to_as_function())
         {
           // It's an ActionScript function.  Call it.
           //log_msg("Calling ActionScript function for onConnect\n");
@@ -802,7 +781,7 @@ xmlsocket_event_connect(const fn_call& fn)
   fn.result->set_bool(val.to_bool()); 
 }
 void
-xmlsocket_event_xml(const fn_call& fn)
+xmlsocket_event_xml(const fn_call& /* fn */)
 {
 #if 0
   as_value* result = fn.result;
